# propshop

Your one-stop shop for material properties.

> Note: This is not currently *your* one-stop shop for material properties, just mine. I am currently using it to interpolate on proprietary property tables, but I plan to generalize it in the future.
